Autoplot nonmem2rx object
# S3 method for nonmem2rx
autoplot(
object,
...,
ncol = 3,
nrow = 3,
log = "",
xlab = "Time",
ylab = "Predictions",
page = FALSE
)a ggplot2 object
an object, whose class will determine the behaviour of autoplot
ignored parameters for nonmem2rx objects
Number of rows and columns
Should "" (neither x nor y), "x", "y", or "xy" (or "yx") be log-scale?
The x and y axis labels
number of page(s) for the individual plots, by default
(FALSE) no pages are print; You can use TRUE for all pages to
print, or list which pages you want to print