Get the most accurate information you can get from NONMEM
nminfo(
file,
mod = ".mod",
xml = ".xml",
ext = ".ext",
cov = ".cov",
phi = ".phi",
lst = ".lst",
useXml = TRUE,
useExt = TRUE,
useCov = TRUE,
usePhi = TRUE,
useLst = TRUE,
strictLst = FALSE,
verbose = FALSE
)list of NONMEM information
nonmem file, like control stream, phi. This function will remove the extension to try to get the right information. It preferentially selects the most accurate estimates from the file.
the NONMEM output extension, defaults to .mod
the NONMEM xml file extension , defaults to .xml
the NONMEM ext file extension, defaults to .ext
the NONMEM covariance file extension, defaults to .cov
the NONMEM eta/phi file extension, defaults to .phi
the NONMEM output extension, defaults to .lst
if present, use the NONMEM xml file to import much of the NONMEM information
if present, use the NONMEM ext file to extract
parameter estimates (default TRUE), otherwise defaults to
parameter estimates extracted in the NONMEM output
if present, use the NONMEM cov file to import the covariance, otherwise import the covariance with list file
if present, use the NONMEM phi file to extract etas
(default TRUE), otherwise defaults to etas in the tables (if
present)
if present, use the NONMEM lst file to extract NONMEM information
The list parsing needs to be correct for a
successful load (default FALSE).
this is a flag to be more verbose when reading information in, by default this is FALSE
Matthew L. Fidler
nminfo(system.file("mods/cpt/runODE032.res", package="nonmem2rx"))
Run the code above in your browser using DataLab